;----------------------------------------------------------------------------------------
; Title:    MediaPortal FirefoxIntegrator
; Version:  1.5
; Date:     03.02.2010
; Author:   ZuNixNuZ
; History:
;	V1.0: - Initial release
;	V1.1: - Startup of Firefox changed, because fullscreen command (F11) 
;         sometimes was not received by Firefox.
;       - Hide mouse cursor in exit sequence changed. 
;         Now cursor will be first moved to most right position.
;       - Colors of info messages changed to black background and white text.
;       - Appear time of info messages changed from 3sec to 1.5 sec. 
;	V1.2: - Added AutoHotkey recommend default settings.
;       - Removed commands to stop media playing in MediaPortal.
;         Now listening music and browsing in Firefox is possible.
;       - Removed minimizing of MediaPortal; not necessary and cause problems
;         while TV is active (TV stopps and volume changes to minimum).
;       - Added Firefox command line argument support.
;         Now FirefoxIntegrator forwards command line arguments
;         like a URL to Firefox.
;	V1.3: - Added key command [h] "Home" to only minimize Firefox but exit 
;         FirfoxIntegrator and go back to MediaPortal Home menue.
;         At the next start of FirefoxIntegrator Firefox will only be maximized.
;	V1.4: - Added new key command [F3] "Info" to switch through all input modes.
;       - New input mode created: "Keyboard input" mode.
;         In this mode all shortcuts are deactivated, 
;         except of F3, F5, F6, F7, F8 and Esc!
;	V1.5: - Display characters at SMS like text input.
;				- Timer at SMS like text input will be reloaded at every keystroke,
;         key input time changed from 1700 to 1200ms.
;				- Characters for key 1 SMS like text input changed.
;				- Keywords AND, OR and NOT added to SMS like text input keys 2 and 6.
;       - Startup of Firefox changed, because fullscreen command (F11) 
;         sometimes was not received by Firefox.
;
; Script functionalities:
; Firefox 3 will be started in fullscreen mode (F11).
; Mediaportal key controls are remapped to Firefox hotkeys.
; Standard keys:
;	1,2,3,4,6,7,8,9        ...Mouse cursor move to all directions
;	5                      ...Mouse click left
;	0                      ...Mouse click right
;	F5 (Rewind)            ...Firefox zoom out
;	F6 (Fast Forward)      ...Firefox zoom in
;	x (Full Screen)        ...Firefox default zoom
;	F7 (Play Previous/Ch-) ...Firefox previous page
;	F8 (Play Next/Ch+)		 ...Firefox next page
;	p (Play)               ...Firefox reload page
;	b (Stop)               ...Firefox stop loading page
;	Space (Pause)          ...Firefox start page
;	y (Show/Hide OSD)      ...Firefox show/hide bookmarks
;	r (Record)             ...Firefox add bookmark
;	d (DVD Menu)           ...Toggle between SMS like text input and mouse control
;	F3 (Info)              ...Switch through all input modes
;	h (Home)               ...Firefox minimize and go back to MediaPortal Home menue
;	Esc, Del, Backspace    ...Firefox exit
;	SMS like text input keys:
;	1                      ..."1" "." "," "-" "?" "!" "'" "@" ":" ";" "/" "\" "(" ")" "*"
;	2                      ..."a" "b" "c" "2" " AND "
;	3                      ..."d" "e" "f" "3"
;	4                      ..."g" "h" "i" "4"
;	5                      ..."j" "k" "l" "5"
;	6                      ..."m" "n" "o" "6" " OR " " NOT "
;	7                      ..."p" "q" "r" "s" "7"
;	8                      ..."t" "u" "v" "8"
;	9                      ..."w" "x" "y" "z" "9"
;	0                      ..." " "Backspace" "0"
;
; Firefox hotkeys:
;	http://support.mozilla.com/kb/Keyboard+shortcuts
; MediaPortal keyboard shortcuts:
;	http://www.team-mediaportal.com/manual/KeyboardShortcuts
;
;----------------------------------------------------------------------------------------


;----------------------------------------------------------------------------------------
; AutoHotkey recommend default settings

#NoEnv	; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input	; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%	; Ensures a consistent starting directory.
#SingleInstance force
;----------------------------------------------------------------------------------------
; Config section

C_MouseSpeed:= 0				; mouse moving speed in the range 0 (fastest) to 100 (slowest)
C_MouseMoveSteps:= 25		; position steps for one single mouse position change
C_KeyInputTime:= 1200		; key input time for SMS like text input

C_Firefox_exe = %A_ProgramFiles%\Mozilla Firefox\firefox.exe
;C_MediaPortal_exe = %A_ProgramFiles%\Team MediaPortal\MediaPortal\MediaPortal.exe

SetTitleMatchMode 2

V_InputMode = 0				; init mode to mouse control

;----------------------------------------------------------------------------------------
; Start sequence

;WinActivate MediaPortal
;WinGet V_MediaPortal_id, ID, MediaPortal	; get handle of MediaPortal

; Start Firefox
IfWinNotExist Mozilla Firefox
{
	IfExist %C_Firefox_exe%
	{
		Run %C_Firefox_exe% %1%			; start Firefox with command line parameter
	}
	else
	{
		MsgBox ERROR: Mozilla Firefox not found!
		ExitApp
	}
}

; wait until Firefox is running (timeout 20sec)
WinWait Mozilla Firefox , , 20
WinMaximize Mozilla Firefox

; activate Firefox and switch to fullscreen
WinActivate Mozilla Firefox
WinWaitActive Mozilla Firefox , , 10	; wait until Firefox is activated (timeout 10sec)
Sleep 300								; wait for switching to fullscreen
SendPlay {F11}							; send F11, fullscreen on

; move mouse to center of screen
MouseMove (A_ScreenWidth /2), (A_ScreenHeight /2), 0

return

;----------------------------------------------------------------------------------------
; Close Firefox and activate MediaPortal

F_Exit:


	ExitApp

return

;----------------------------------------------------------------------------------------
; Minimize Firefox and go back to MediaPortal Home menue

F_Minimize:

	
	ExitApp

return

;----------------------------------------------------------------------------------------
; Remapp MediaPortal keys to Firefox
; ! = ALT
; + = SHIFT
; ^ = CTRL


; "Home" -> Minimize Firefox
h::	
	if V_InputMode != 9
	{
		goto F_Minimize
	}
	else
	{
		SendPlay {h}	; In Keyboard input mode use original pressed key
	}
return


; "Info" -> Switch through all input modes
F3::
	if V_InputMode = 0
	{
		; SMS text input
		V_InputMode = 1
		Progress , b1 fs22 cwBlack ctWhite zh0, SMS text input, , , Arial
		Sleep 1500
		Progress , Off
	}
	else if V_InputMode = 1
	{
		; Keyboard input - Shortcuts are off!
		V_InputMode = 9
		Progress , b1 fs22 cwBlack ctWhite zh0, Keyboard input, , , Arial
		Sleep 1500
		Progress , Off	
	}
	else
	{
		; Mouse control
		V_InputMode = 0
		Progress , b1 fs22 cwBlack ctWhite zh0, Mouse control, , , Arial
		Sleep 1500
		Progress , Off
	}
return


;----------------------------------------------------------------------------------------
; count key presses for SMS like key input or move mouse cursor

1::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_1, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_1_Cnt < 15		; limit key counts
				V_Key_1_Cnt += 1
			else
				V_Key_1_Cnt = 1
			; Show key input
			V_KeyCntTextArray1  := "[1] .  ,  -  ?  !  '  @  :  `;  /  \  (  )  * "
			V_KeyCntTextArray2  := " 1 [.] ,  -  ?  !  '  @  :  `;  /  \  (  )  * "
			V_KeyCntTextArray3  := " 1  . [,] -  ?  !  '  @  :  `;  /  \  (  )  * "
			V_KeyCntTextArray4  := " 1  .  , [-] ?  !  '  @  :  `;  /  \  (  )  * "
			V_KeyCntTextArray5  := " 1  .  ,  - [?] !  '  @  :  `;  /  \  (  )  * "
			V_KeyCntTextArray6  := " 1  .  ,  -  ? [!] '  @  :  `;  /  \  (  )  * "
			V_KeyCntTextArray7  := " 1  .  ,  -  ?  ! ['] @  :  `;  /  \  (  )  * "
			V_KeyCntTextArray8  := " 1  .  ,  -  ?  !  ' [@] :  `;  /  \  (  )  * "
			V_KeyCntTextArray9  := " 1  .  ,  -  ?  !  '  @ [:] `;  /  \  (  )  * "
			V_KeyCntTextArray10 := " 1  .  ,  -  ?  !  '  @  : [`;] /  \  (  )  * "
			V_KeyCntTextArray11 := " 1  .  ,  -  ?  !  '  @  :  `; [/] \  (  )  * "
			V_KeyCntTextArray12 := " 1  .  ,  -  ?  !  '  @  :  `;  / [\] (  )  * "
			V_KeyCntTextArray13 := " 1  .  ,  -  ?  !  '  @  :  `;  /  \ [(] )  * "
			V_KeyCntTextArray14 := " 1  .  ,  -  ?  !  '  @  :  `;  /  \  ( [)] * "
			V_KeyCntTextArray15 := " 1  .  ,  -  ?  !  '  @  :  `;  /  \  (  ) [*]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_1_Cnt%
			Progress , b1 w500 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse up + left
			MouseMove C_MouseMoveSteps *(-1) , C_MouseMoveSteps *(-1), C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {1}	; In Keyboard input mode use original pressed key
	}
return

2::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_2, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_2_Cnt < 5		; limit key counts
				V_Key_2_Cnt += 1
			else
				V_Key_2_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[a] b  c  2  AND "
			V_KeyCntTextArray2 := " a [b] c  2  AND "
			V_KeyCntTextArray3 := " a  b [c] 2  AND "
			V_KeyCntTextArray4 := " a  b  c [2] AND "
			V_KeyCntTextArray5 := " a  b  c  2 [AND]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_2_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse up
			MouseMove 0 , C_MouseMoveSteps *(-1), C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {2}	; In Keyboard input mode use original pressed key
	}
return

3::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_3, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_3_Cnt < 4		; limit key counts
				V_Key_3_Cnt += 1
			else
				V_Key_3_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[d] e  f  3 "
			V_KeyCntTextArray2 := " d [e] f  3 "
			V_KeyCntTextArray3 := " d  e [f] 3 "
			V_KeyCntTextArray4 := " d  e  f [3]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_3_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse up + rigth
			MouseMove C_MouseMoveSteps , C_MouseMoveSteps *(-1), C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {3}	; In Keyboard input mode use original pressed key
	}
return

4::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_4, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_4_Cnt < 4		; limit key counts
				V_Key_4_Cnt += 1
			else
				V_Key_4_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[g] h  i  4 "
			V_KeyCntTextArray2 := " g [h] i  4 "
			V_KeyCntTextArray3 := " g  h [i] 4 "
			V_KeyCntTextArray4 := " g  h  i [4]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_4_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse left
			MouseMove C_MouseMoveSteps *(-1) , 0 , C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {4}	; In Keyboard input mode use original pressed key
	}
return

5::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_5, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_5_Cnt < 4		; limit key counts
				V_Key_5_Cnt += 1
			else
				V_Key_5_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[j] k  l  5 "
			V_KeyCntTextArray2 := " j [k] l  5 "
			V_KeyCntTextArray3 := " j  k [l] 5 "
			V_KeyCntTextArray4 := " j  k  l [5]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_5_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse left click
			MouseClick , left
		}
	}
	else
	{
		SendPlay {5}	; In Keyboard input mode use original pressed key
	}
return

6::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_6, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_6_Cnt < 6		; limit key counts
				V_Key_6_Cnt += 1
			else
				V_Key_6_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[m] n  o  6  OR  NOT "
			V_KeyCntTextArray2 := " m [n] o  6  OR  NOT "
			V_KeyCntTextArray3 := " m  n [o] 6  OR  NOT "
			V_KeyCntTextArray4 := " m  n  o [6] OR  NOT "
			V_KeyCntTextArray5 := " m  n  o  6 [OR] NOT "
			V_KeyCntTextArray6 := " m  n  o  6  OR [NOT]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_6_Cnt%
			Progress , b1 w400 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse right
			MouseMove C_MouseMoveSteps , 0 , C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {6}	; In Keyboard input mode use original pressed key
	}
return

7::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_7, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_7_Cnt < 5		; limit key counts
				V_Key_7_Cnt += 1
			else
				V_Key_7_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[p] q  r  s  7 "
			V_KeyCntTextArray2 := " p [q] r  s  7 "
			V_KeyCntTextArray3 := " p  q [r] s  7 "
			V_KeyCntTextArray4 := " p  q  r [s] 7 "
			V_KeyCntTextArray5 := " p  q  r  s [7]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_7_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse down + left
			MouseMove C_MouseMoveSteps *(-1) , C_MouseMoveSteps , C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {7}	; In Keyboard input mode use original pressed key
	}
return

8::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_8, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_8_Cnt < 4		; limit key counts
				V_Key_8_Cnt += 1
			else
				V_Key_8_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[t] u  v  8 "
			V_KeyCntTextArray2 := " t [u] v  8 "
			V_KeyCntTextArray3 := " t  u [v] 8 "
			V_KeyCntTextArray4 := " t  u  v [8]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_8_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse down
			MouseMove 0 , C_MouseMoveSteps , C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {8}	; In Keyboard input mode use original pressed key
	}
return

9::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_9, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_9_Cnt < 5		; limit key counts
				V_Key_9_Cnt += 1
			else
				V_Key_9_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[w] x  y  z  9 "
			V_KeyCntTextArray2 := " w [x] y  z  9 "
			V_KeyCntTextArray3 := " w  x [y] z  9 "
			V_KeyCntTextArray4 := " w  x  y [z] 9 "
			V_KeyCntTextArray5 := " w  x  y  z [9]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_9_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse down + right
			MouseMove C_MouseMoveSteps , C_MouseMoveSteps , C_MouseSpeed , R
		}
	}
	else
	{
		SendPlay {9}	; In Keyboard input mode use original pressed key
	}
return

0::
	if V_InputMode != 9
	{
		if (V_InputMode = 1)
		{
			; reload timer and count key presses 
			SetTimer , F_Key_0, %C_KeyInputTime%	; wait for more key presses within given time
			if V_Key_0_Cnt < 3		; limit key counts
				V_Key_0_Cnt += 1
			else
				V_Key_0_Cnt = 1
			; Show key input
			V_KeyCntTextArray1 := "[Space] BS  0 "
			V_KeyCntTextArray2 := " Space [BS] 0 "
			V_KeyCntTextArray3 := " Space  BS [0]"
			V_ProgressSubText := V_KeyCntTextArray%V_Key_0_Cnt%
			Progress , b1 w300 fs22 cwBlack ctWhite zh0, %V_ProgressSubText%, , , Arial
		}
		else
		{
			; mouse right click
			MouseClick , right
		}
	}
	else
	{
		SendPlay {0}	; In Keyboard input mode use original pressed key
	}
return

;----------------------------------------------------------------------------------------
; SMS like text input
;

; Key [1]
F_Key_1:
	SetTimer , F_Key_1 , off
	if V_Key_1_Cnt = 1				; key was pressed 1 time
	{
		SendPlay {1}
	}
	else if V_Key_1_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {.}
	}
	else if V_Key_1_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {,}
	}
	else if V_Key_1_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {-}
	}
	else if V_Key_1_Cnt = 5		; key was pressed 5 times
	{
		SendPlay {?}
	}
	else if V_Key_1_Cnt = 6		; key was pressed 6 times
	{
		SendPlay {!}
	}
	else if V_Key_1_Cnt = 7		; key was pressed 7 times
	{
		SendPlay {'}
	}
	else if V_Key_1_Cnt = 8		; key was pressed 8 times
	{
		SendPlay {@}
	}
	else if V_Key_1_Cnt = 9		; key was pressed 9 times
	{
		SendPlay {:}
	}
	else if V_Key_1_Cnt = 10	; key was pressed 10 times
	{
		SendPlay {;}
	}
	else if V_Key_1_Cnt = 11	; key was pressed 11 times
	{
		SendPlay {/}
	}
	else if V_Key_1_Cnt = 12	; key was pressed 12 times
	{
		SendPlay {\}
	}
	else if V_Key_1_Cnt = 13	; key was pressed 13 times
	{
		SendPlay {(}
	}
	else if V_Key_1_Cnt = 14	; key was pressed 14 times
	{
		SendPlay {)}
	}
	else if V_Key_1_Cnt = 15	; key was pressed 15 times
	{
		SendPlay {*}
	}
	V_Key_1_Cnt = 0				; reset key count
	Progress , Off
return

; Key [2]
F_Key_2:
	SetTimer , F_Key_2 , off
	if V_Key_2_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {a}
	}
	else if V_Key_2_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {b}
	}
	else if V_Key_2_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {c}
	}
	else if V_Key_2_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {2}
	}
	else if V_Key_2_Cnt = 5		; key was pressed 5 times
	{
		SendPlay {Space}{A}{N}{D}{Space}
	}
	V_Key_2_Cnt = 0				; reset key count
	Progress , Off
return

; Key [3]
F_Key_3:
	SetTimer , F_Key_3 , off
	if V_Key_3_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {d}
	}
	else if V_Key_3_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {e}
	}
	else if V_Key_3_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {f}
	}
	else if V_Key_3_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {3}
	}
	V_Key_3_Cnt = 0				; reset key count
	Progress , Off
return

; Key [4]
F_Key_4:
	SetTimer , F_Key_4 , off
	if V_Key_4_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {g}
	}
	else if V_Key_4_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {h}
	}
	else if V_Key_4_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {i}
	}
	else if V_Key_4_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {4}
	}
	V_Key_4_Cnt = 0				; reset key count
	Progress , Off
return

; Key [5]
F_Key_5:
	SetTimer , F_Key_5 , off
	if V_Key_5_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {j}
	}
	else if V_Key_5_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {k}
	}
	else if V_Key_5_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {l}
	}
	else if V_Key_5_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {5}
	}
	V_Key_5_Cnt = 0				; reset key count
	Progress , Off
return

; Key [6]
F_Key_6:
	SetTimer , F_Key_6 , off
	if V_Key_6_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {m}
	}
	else if V_Key_6_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {n}
	}
	else if V_Key_6_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {o}
	}
	else if V_Key_6_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {6}
	}
	else if V_Key_6_Cnt = 5		; key was pressed 5 times
	{
		SendPlay {Space}{O}{R}{Space}
	}
	else if V_Key_6_Cnt = 6		; key was pressed 6 times
	{
		SendPlay {Space}{N}{O}{T}{Space}
	}
	V_Key_6_Cnt = 0				; reset key count
	Progress , Off
return

; Key [7]
F_Key_7:
	SetTimer , F_Key_7 , off
	if V_Key_7_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {p}
	}
	else if V_Key_7_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {q}
	}
	else if V_Key_7_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {r}
	}
	else if V_Key_7_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {s}
	}
	else if V_Key_7_Cnt = 5		; key was pressed 5 times
	{
		SendPlay {7}
	}
	V_Key_7_Cnt = 0				; reset key count
	Progress , Off
return

; Key [8]
F_Key_8:
	SetTimer , F_Key_8 , off
	if V_Key_8_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {t}
	}
	else if V_Key_8_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {u}
	}
	else if V_Key_8_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {v}
	}
	else if V_Key_8_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {8}
	}
	V_Key_8_Cnt = 0				; reset key count
	Progress , Off
return

; Key [9]
F_Key_9:
	SetTimer , F_Key_9 , off
	if V_Key_9_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {w}
	}
	else if V_Key_9_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {x}
	}
	else if V_Key_9_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {y}
	}
	else if V_Key_9_Cnt = 4		; key was pressed 4 times
	{
		SendPlay {z}
	}
	else if V_Key_9_Cnt = 5		; key was pressed 5 times
	{
		SendPlay {9}
	}
	V_Key_9_Cnt = 0				; reset key count
	Progress , Off
return

; Key [0]
F_Key_0:
	SetTimer , F_Key_0 , off
	if V_Key_0_Cnt = 1			; key was pressed 1 time
	{
		SendPlay {Space}
	}
	else if V_Key_0_Cnt = 2		; key was pressed 2 times
	{
		SendPlay {Backspace}
	}
	else if V_Key_0_Cnt = 3		; key was pressed 3 times
	{
		SendPlay {0}
	}
	V_Key_0_Cnt = 0				; reset key count
	Progress , Off
return
